@@ -4,7 +4,65 @@ import pandas as pd
 from sqlalchemy import create_engine
 from sqlalchemy.exc import OperationalError
 import pymysql
+from urllib.request import urlopen
+import json
 
+class getJson:
+   """
+   getJson from url
+   """
+
+   def __init__(self):
+      self.nada=0
+
+   def readJsonUrlToDf(self,url):
+       continuar=True
+       intentos=0
+       intentosMax=6
+       result=pd.DataFrame()
+       while(continuar):
+           try:
+               with urlopen(url,timeout=28) as response:
+                   body = response.read()
+                   data = json.loads(body)
+               result=pd.DataFrame(data)
+               if(int(result.shape[0])>0):
+                   continuar=False
+           except Exception as e:
+               print('err readJsonUrlToDf;',e)
+
+           intentos=intentos+1
+           if(intentos<=intentosMax):
+               continuar=False
+           if(~continuar):
+               return result
+       return result
+
+   def readJsonUrlToInfoData(self,url):
+       continuar=True
+       intentos=0
+       intentosMax=6
+       result=pd.DataFrame()
+       while(continuar):
+           try:
+               with urlopen(url,timeout=28) as response:
+                   body = response.read()
+                   info = json.loads(body)["info"]
+                   data = json.loads(body)["data"]
+                   #print(info)
+                   #print(data)
+               result=pd.DataFrame(data)
+               if(int(result.shape[0])>0):
+                   continuar=False
+           except Exception as e:
+               print('err readJsonUrlToInfoData;',e)
+
+           intentos=intentos+1
+           if(intentos<=intentosMax):
+               continuar=False
+           if(~continuar):
+               return info,result
+       return info,result
 
 class hora:
    """
@@ -100,7 +158,7 @@ class mysql:
       self.passx=passx
       self.dbx=dbx
 
-   def mysqlQueryRe(self,q,intentos=3,sleepStep=1):
+   def query(self,q,intentos=3,sleepStep=1):
       looper=0
       intentos=int(intentos)
       valid=False
@@ -142,3 +200,4 @@ class mysql:
          return ''
       finally:
          dbConnection.close()
+
